Glossary
--------

modulus:
    An operator that works on integers and yields the remainder when one
    number is divided by another. In C++ it is denoted with a percent
    sign (%).

conditional:
    A block of statements that may or may not be executed depending on
    some condition.

chaining:
    A way of joining several conditional statements in sequence.

nesting:
    Putting a conditional statement inside one or both branches of
    another conditional statement.

recursion:
    The process of calling the same function you are currently
    executing.

infinite recursion:
    A function that calls itself recursively without every reaching the
    base case. Eventually an infinite recursion will cause a run-time
    error.


.. dragndrop:: chapter_four_glossary_1
   :feedback: Try again!
   :match_1: modulus|||An operator that works on integers and yields the remainder when one number is divided by another.
   :match_2: chaining|||A way of joining several conditional statements in sequence.
   :match_3: nesting|||Putting a conditional statement inside one or both branches of another conditional statement.
    

.. dragndrop:: chapter_four_glossary_2
   :feedback: Try again!
   :match_1: conditional|||A block of statements that may or may not be executed depending on some condition.
   :match_2: recursion|||The process of calling the same function you are currently executing.
   :match_3: infinite recursion|||The process of making recursive calls without every reaching the base case.
